RtcNetworkStreamFactory class

Builds WebRTC streams for a session.

Also where the mesh is built: this is the first place a session object is in hand, and the mesh cannot exist before one — it is keyed on this node's uId and addressed by the coordination stream's name.

Inheritance

Constructors

RtcNetworkStreamFactory(RtcTransport transport)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transport → RtcTransport
final

Methods

createCoordinationStream(CoordinationStreamConfig config, CoordinationSession session) → Future<RtcCoordinationStream>
Creates a coordination stream with the given configuration and session context.
override
createDataStream(DataStreamConfig config, CoordinationSession session) → Future<RtcDataStream>
Creates a data stream with the given configuration and session context.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited